@@ -4,6 +4,7 @@ import warnings
 
 from .cached_property import cached_property
 from .config_utils import Config
+from .crypt import Crypt
 from .db_utils import AioMysql
 from .db_utils import AioRedis
 from .db_utils import Mongo
@@ -65,5 +66,5 @@ __all__ = [
     'Config', 'Logger', 'WatchedFileHandler',
     'Mongo', 'MongoClient', 'Redis', 'AioRedis', 'Motor', 'MotorClient',
     'Mysql', 'AioMysql', 'Pika', 'AioPika',
-    'Request', 'Response', 'Chrome',
+    'Request', 'Response', 'Chrome', 'Crypt'
 ]
