@@ -282,6 +282,7 @@ class Mysql:
                           db=db, charset=charset, init_command=init_command,
                           sql_mode=sql_mode, autocommit=autocommit, **kwargs)
         self._conn = None
+        self._pool = None
         self._max_idle_time = max_idle_time
         self._last_use_time = time.time()
 
@@ -289,7 +290,7 @@ class Mysql:
         self.close()
 
     def close(self):
-        if getattr(self, "_db", None) is not None:
+        if getattr(self, "_conn", None) is not None:
             self._conn.close()
             self._conn = None
 
@@ -357,14 +358,20 @@ Connection._read_bytes = _read_bytes
 
 class AioMysql(Mysql):
 
+    async def close(self):
+        if getattr(self, "_pool", None) is not None:
+            self._pool.close()
+            await self._pool.wait_closed()
+
     async def reconnect(self):
-        self.close()
-        self._conn = await aiomysql.connect(**self._args)
+        await self.close()
+        self._pool = await aiomysql.create_pool(minsize=5, maxsize=10, **self._args)
 
     async def _ensure_connected(self):
-        if self._conn is None or (time.time() - self._last_use_time > self._max_idle_time):
+        if self._pool is None or (time.time() - self._last_use_time > self._max_idle_time):
             await self.reconnect()
         self._last_use_time = time.time()
+        self._conn = await self._pool.acquire()
 
     async def iter(self, sql, *args):
         await self._ensure_connected()
