@@ -253,7 +253,7 @@ class BaseRequest(metaclass=RequestMeta):
             'connection': 'keep-alive',
             'accept-encoding': 'gzip,deflate,sdch',
             'accept-language': 'zh-CN,zh;q=0.8,en;q=0.6',
-            'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_4) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/68.0.3440.75 Safari/537.36'
+            'user-agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_14_5) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/80.0.3987.132 Safari/537.36'
         }
         self.headers.update(kwargs.get('headers', {}))
 
@@ -675,7 +675,7 @@ class Pycurl(BaseRequest):
         curl.setopt(pycurl.HTTPHEADER, header_list)
 
         if cookies:
-            cookie_str = ';'.join([f'{to_str(k)}={to_str(v)}' for k, v in cookies.items()])
+            cookie_str = ';'.join([f"{to_str(k)}={urllib.parse.quote(to_str(v), safe=string.printable)}" for k, v in cookies.items()])
             curl.setopt(pycurl.COOKIE, cookie_str)
 
         if kwargs['progress']:
